<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright
Custom Field Type:
	calendar date picker
Name:
	calendar_date_picker_props.cfm
Summary:
	A custom checkbox field that is used to select dates within the Calendar App
ADF Requirements:
	date_1_0
	scripts_1_0
History:
	2011-07-28 - GAC - Created
	2014-09-25 - GAC - Removed deprecated doLabel and jsLabelUpdater js calls
					 - Added the fieldVersion variable
	2015-05-13 - DRM - Removed jQuery from validation, use plain js instead
					 - Bumped field version
					 - Remove displayType support, always use jQuery UI datepicker
					 - Add isMultiline()
					 - Add formatting options explanation
	2015-05-20 - DRM - split out formatting tokens explanations for clarity, adjust css
	2016-02-25 - DRM - Insufficient minimum height for current popup calendar
					 	  - Bump field version
--->

<cfscript>
	// Variable for the version of the field - Display in Props UI.
	fieldVersion = "2.0.1";
	
	// initialize some of the attributes variables
	typeid = attributes.typeid;
	prefix = attributes.prefix;
	formname = attributes.formname;
	currentValues = attributes.currentValues;
	
	if( not structKeyExists(currentValues, "fldID") )
		currentValues.fldID = "";
	if( not structKeyExists(currentValues, "displayFormat") )
		currentValues.displayFormat = "";
	if( not structKeyExists(currentValues, "uiTheme") )
		currentValues.uiTheme = "";
	if( not structKeyExists(currentValues, "fldIcon") )
		currentValues.fldIcon = "none";
	if( not structKeyExists(currentValues, "fldClearDate") )
		currentValues.fldClearDate = 'no';
</cfscript>

<cfoutput>
	<style type="text/css">
		.alignTop {vertical-align: top;}
		.detailsTable {border-collapse: collapse; margin-bottom: 2px;}
		.detailsTable th, .detailsTable td {font-size: 9px; line-height: 11px; text-align: left;}
		.detailsTable th {font-weight: bold; padding: 0 5px 0 0;}
		.detailsTable td {padding: 0 15px 0 0;}
	</style>
	<script language="JavaScript" type="text/javascript">
		// register the fields with global props object
		fieldProperties['#typeid#'].paramFields = '#prefix#fldID,#prefix#displayFormat,#prefix#uiTheme,#prefix#fldIcon,#prefix#fldClearDate';
	</script>

	<table>
		<tr class="alignTop">
			<td class="cs_dlgLabelSmall">Display Format:</td>
			<td class="cs_dlgLabelSmall" style="padding:">
				<input type="text" name="#prefix#displayFormat" id="#prefix#displayFormat" class="cs_dlgControl" value="#currentValues.displayFormat#" size="40"><br>
				<table class="detailsTable">
					<tr>
						<th>d</th>
						<td>day without leading zero</td>
						<th>dd</th>
						<td>day with leading zero</td>
						<th>D</th>
						<td>weekday name short</td>
						<th>DD</th>
						<td>weekday name long</td>
					</tr>
					<tr>
						<th>m</th>
						<td>month without leading zero</td>
						<th>mm</th>
						<td>month with leading zero</td>
						<th>M</th>
						<td>month name short</td>
						<th>MM</th>
						<td>month name long</td>
					</tr>
					<tr>
						<th>y</th>
						<td>year two digits</td>
						<th>yy</th>
						<td>year four digits</td>
					</tr>
				</table>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">UI Theme:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#uiTheme" id="#prefix#uiTheme" class="cs_dlgControl" value="#currentValues.uiTheme#" size="40">
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Field ID:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#fldID" id="#prefix#fldID" class="cs_dlgControl" value="#currentValues.fldID#" size="40">
				<br><span>Please enter the field ID to be used via JavaScript.  If blank, will use default CS field name.</span>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Show Icon Next To Field:</td>
			<td class="cs_dlgLabelSmall">
				<label>
					<input type="radio" name="#prefix#fldIcon" id="#prefix#fldIcon_none" value="none" <cfif currentValues.fldIcon eq 'none'>checked</cfif>>No
				</label>
				&nbsp;&nbsp;
				<label>
					<input type="radio" name="#prefix#fldIcon" id="#prefix#fldIcon_calendar" value="calendar" <cfif currentValues.fldIcon eq 'calendar'>checked</cfif>>
					<img class="ui-datepicker-trigger" id="#prefix#fldIcon_dateIMG" src="/ADF/apps/pt_calendar/images/ui_calendar.gif" alt="calendar" title="Select a Date...">
				</label>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" valign="top">Show Clear Date Link:</td>
			<td class="cs_dlgLabelSmall">
				<label><input type="radio" name="#prefix#fldClearDate" id="#prefix#fldClearDate_no" value="no" <cfif currentValues.fldClearDate eq 'no'>checked</cfif>>No</label>
				&nbsp;&nbsp;
				<label><input type="radio" name="#prefix#fldClearDate" id="#prefix#fldClearDate_yes" value="yes" <cfif currentValues.fldClearDate eq 'yes'>checked</cfif>>Yes</label>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" colspan="2" style="font-size:7pt;">
				<hr />
				ADF Custom Field v#fieldVersion#
			</td>
		</tr>
	</table>
</cfoutput>