<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	D. Mallick
Custom Field Type:
	calendar date picker
Name:
	calendar_date_picker_render.cfc
Summary:
	Renderer for custom text field that is used to select dates within the Calendar App
ADF Requirements:
	date_1_0
	scripts_1_0
History:
	2011-07-28 - GAC - Created
	2015-05-01 - DJM - Converted to CFC
	2015-05-13 - DRM - Remove displayType support, always use jQuery UI datepicker
							 Add isMultiline()
	2015-05-20 - DRM - Add and use formatLikePlugin() to format date in cf when dlg first opens like the plugin does in js
						  - Add getMinHeight()
						  - Move clear link css inside cfoutput, it wasn't rendering
--->
<cfcomponent displayName="CalendarDatePicker Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var readOnly = (arguments.displayMode EQ 'readonly') ? true : false;
		var displayValue = "";
		var useCalendarIcon = false;
		// Get from the App.cfc so all date fields use the same day begin time in their date/time stamp
		var standardDayBeginTime = application.ptCalendar.getDayBeginTime();
		// Set the Time mask to the App standard
		var cfDateMask = application.ptCalendar.getDisplayCFdateMask();
		
		// Pass new date URL variable through to the Calendar Picker
		if (StructkeyExists(Request.Params, "newSelectedDate"))
			currentValue = Request.params.newSelectedDate;
	
		if ( LEN(TRIM(currentValue)) )
		{
			// Fix bad or incorrect date/time entries
			currentValue = application.ptCalendar.date.csDateFormat(currentValue,currentValue);
			// Strip the standardDayBeginTime from the currentValue and format date for Display
			displayValue = formatLikePlugin(trim(replace(currentValue, standardDayBeginTime, "", "ALL")), inputParameters.displayFormat);
		}
		
		inputParameters = setDefaultParameters(argumentCollection=arguments);
		
		// Set Default Icon Options
		if ( inputParameters.fldIcon EQ "calendar")
			useCalendarIcon = true; // plugin js handles rendering it

		if ( LEN(TRIM(inputParameters.displayFormat)) EQ 0 )
			inputParameters.displayFormat = "m/d/yy";
	</cfscript>
	
	<cfscript>
		renderJSFunctions(argumentCollection=arguments,fieldParameters=inputParameters,standardDayBeginTime=standardDayBeginTime,useCalendarIcon=useCalendarIcon);
	</cfscript>
	
	<cfoutput>
		<cfif inputParameters.fldClearDate EQ 'yes'>
			<style>.#arguments.fieldName#_smalllink {font-size: 9px;}</style>
		</cfif>

		<input type="text" name="#arguments.fieldName#_picker" id="#inputParameters.fldID#_picker" value="#displayValue#" size="25" autocomplete="off"<cfif readOnly> disabled="disabled"</cfif>>
		<!--- hidden field to store the value --->
		<input type="hidden" name="#arguments.fieldName#" id="#inputParameters.fldID#" value="#currentValue#">
		<!--- <input type='text' name='#arguments.fieldName#_dtObject' id='#inputParameters.fldID#_dtObject' value=''> --->
		<cfif inputParameters.fldClearDate EQ 'yes'>
			<br><a href="javascript:;" id="#arguments.fieldName#_cleardate" class="#arguments.fieldName#_smalllink">Clear Date</a>
		</cfif>
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldParameters" type="struct" required="yes">
	<cfargument name="standardDayBeginTime" type="string" required="yes">
	<cfargument name="useCalendarIcon" type="string" required="yes">

	<cfscript>
		var inputParameters = Duplicate(arguments.fieldParameters);
	</cfscript>
<cfoutput><script type="text/javascript">
<!--
jQuery(function() {

	// jQueryUI Date Picker
	// http://jqueryui.com/demos/datepicker/
	// jQueryUI Date Picker Options
	var datePickerOptions_#arguments.fieldName# = {
			changeMonth : true
			,changeYear : true
			,showButtonPanel : true
			,constrainInput : false 
			,dateFormat : '#inputParameters.displayFormat#'
			<cfif arguments.useCalendarIcon>
			,showOn : "both" //button
			,buttonImage : "/ADF/apps/pt_calendar/images/ui_calendar.gif"
			,buttonImageOnly : true
			,buttonText : 'Choose a Date...'
			<cfelse>
			,showOn : "focus"
			</cfif>
		};
		
	// Calendar Picker Fields
	jQuery("###inputParameters.fldID#_picker").datepicker( datePickerOptions_#arguments.fieldName# );

	// Onchange populate the Hidden field that stores the data
	jQuery("###inputParameters.fldID#_picker").change(function(){
												//console.log('change');
		var dateStr = jQuery("###inputParameters.fldID#_picker").val();
		
		// Get the Standard/Dummy Time 
		var timeStr = '#arguments.standardDayBeginTime#';
		
		var csDate = "";
		var jsDateObj = "";
		
		// Use DateJS lib to parse the concatenated date/time into a date/time object
		if ( jQuery.trim(dateStr).length && jQuery.trim(timeStr).length )
			jsDateObj = Date.parse(dateStr + " " + timeStr);

		// Use the dateFormat Lib to convert the date/time object to a CS Date string
		if ( jQuery.trim(jsDateObj).length )
			csDate=dateFormat(jsDateObj, "yyyy-mm-dd HH:MM:ss ");

		// Set the value to the hidden field to be stored
												//console.log(csDate);
		jQuery("input[name=#arguments.fieldName#]").val(csDate);
		
		// jQuery("input[name=#arguments.fieldName#_dtObject]").val(jsDateObj);
	});
	
	<cfif inputParameters.fldClearDate EQ 'yes'>
	jQuery('###arguments.fieldName#_cleardate').click(function() {
		jQuery("input[name=#arguments.fieldName#_picker]").val('');
		jQuery("input[name=#arguments.fieldName#]").val('');
	});
	</cfif>
});
//-->
</script></cfoutput>
</cffunction>

<cffunction name="setDefaultParameters" returntype="struct" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		// Validate if the property field has been defined
		if ( NOT StructKeyExists(inputParameters, "displayType") OR LEN(inputParameters.displayType) LTE 0 )
			inputParameters.displayType = "UIdatepicker";
		if ( NOT StructKeyExists(inputParameters, "displayFormat") OR LEN(inputParameters.displayFormat) LTE 0 )
			inputParameters.displayFormat = "";
		if ( NOT StructKeyExists(inputParameters, "uiTheme") OR LEN(inputParameters.uiTheme) LTE 0 )
			inputParameters.uiTheme = application.ptCalendar.getUItheme(); // use the UI theme from the Configuration Element
		if ( NOT StructKeyExists(inputParameters, "fldIcon") OR LEN(inputParameters.fldIcon) LTE 0 )
			inputParameters.fldIcon = "none";
		if ( NOT StructKeyExists(inputParameters, "fldClearDate") OR LEN(inputParameters.fldClearDate) LTE 0 )
			inputParameters.fldClearDate = "no";
		if ( NOT StructKeyExists(inputParameters, "fldID") OR LEN(inputParameters.fldID) LTE 0 )
			inputParameters.fldID = TRIM(arguments.fieldName);
		else 
			inputParameters.fldID = TRIM(inputParameters.fldID);
		
		return inputParameters;
	</cfscript>
</cffunction>

<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "TEXT")';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please select a value for the #arguments.label# field.";
	}

	private boolean function isMultiline()
	{
		return structKeyExists(arguments.parameters, "fldClearDate") && arguments.parameters.fldClearDate == "yes";
	}

	// field types that require some particular minimum height should return the desired number of pixels
	public numeric function getMinHeight()
	{
		return 250;
	}

	// formats passed date using a format in the style used by the jQuery UI datepicker plugin
	function formatLikePlugin(value, format)
	{
		var jsTokens = "DD,D,MM,M,YY,Y";
		var cfTokens = "dddd,ddd,mmmm,mmm,yyyy,yy";
		var cfFormat = replace(arguments.format, "y", "Y", "ALL"); // done this way so y replacement doesn't replace yy result, if you see what I mean
		cfFormat = replaceList(cfFormat, jsTokens, cfTokens);
		return dateFormat(arguments.value, cfFormat);
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,jQueryUI,DateJS,DateFormat");
	}
	public string function loadResourceDependencies()
	{
		// jQuery Headers
		application.ptCalendar.scripts.loadJQuery();
		application.ptCalendar.scripts.loadJQueryUI(themeName=arguments.parameters.uiTheme);
		// Load the DateJS Plugin Headers
		application.ptCalendar.scripts.loadDateJS();
		// Load the DateFormat Plugin Headers
		application.ptCalendar.scripts.loadDateFormat();
	}
</cfscript>
</cfcomponent>