<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright 
Custom Field Type:
	Calendar Time Picker Field
Name:
	calendar_time_picker_props.cfm
Summary:
	Custom Field that renders a timepicker field
History:
	2011-08-18 - GAC - Created
	2014-09-25 - GAC - Removed deprecated doLabel and jsLabelUpdater js calls
					 - Added the fieldVersion variable
	2015-05-20 - DRM - Removed jQuery from validation, use plain js instead
					 - Removed displayType prop, use jQueryUI UItimepickerAddon always
					 - Added validation to reject 24 hr formats w am/pm indicator, that's nonsense, and plugin won't preset correctly
					 - Added formatting options explanation
					 - Cleaned up radio btns html
					 - Bumped field version
	2016-02-25 - DRM - Use application default theme if none is configured
						  - Bump field version
--->
<cfscript>
	// Variable for the version of the field - Display in Props UI.
	fieldVersion = "2.0.1";
	
	// initialize some of the attributes variables
	typeid = attributes.typeid;
	prefix = attributes.prefix;
	formname = attributes.formname;
	currentValues = attributes.currentValues;
	
	if( not structKeyExists(currentValues, "fldID") )
		currentValues.fldID = "";
	if( not structKeyExists(currentValues, "displayFormat") )
		currentValues.displayFormat = "";
	if( not structKeyExists(currentValues, "uiTheme") or currentValues.uiTheme eq "")
		currentValues.uiTheme = application.ptCalendar.getUItheme(); // use the UI theme from the Configuration Element
	if( not structKeyExists(currentValues, "fldIcon") )
		currentValues.fldIcon = "none";
</cfscript>

<cfoutput>
	<style type="text/css">
		.alignTop {vertical-align: top;}
		.detailsTable {border-collapse: collapse; margin-bottom: 2px;}
		.detailsTable th, .detailsTable td {font-size: 9px; line-height: 11px; text-align: left;}
		.detailsTable th {font-weight: bold; padding: 0 5px 0 0;}
		.detailsTable td {padding: 0 15px 0 0;}
	</style>
	<script language="JavaScript" type="text/javascript">
		// register the fields with global props object
		fieldProperties['#typeid#'].paramFields = '#prefix#fldID,#prefix#displayFormat,#prefix#uiTheme,#prefix#fldIcon';

		// allows this field to have a common onSubmit Validator
		fieldProperties['#typeid#'].jsValidator = '#prefix#doValidate';
		function #prefix#doValidate()
		{
			var fld = document.getElementById('#prefix#displayFormat');
			if (fld.value.match(/H.*[tT]/))
			{
				fld.select();
				alert('24 hour time formats cannot have an AM/PM indicator.');
				return false;
			}
			return true;
		}
	</script>
	<table>
		<tr class="alignTop">
			<td class="cs_dlgLabelSmall">Display Format:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#displayFormat" id="#prefix#displayFormat" class="cs_dlgControl" value="#currentValues.displayFormat#" size="40"><br>
				<table class="detailsTable">
					<tr>
						<th>H</th>
						<td>hour without leading zero 24 hr</td>
						<th>HH</th>
						<td>hour with leading zero 24 hr</td>
					</tr>
					<tr>
						<th>h</th>
						<td>hour without leading zero 12 hr</td>
						<th>hh</th>
						<td>hour with leading zero 12 hr</td>
					</tr>
					<tr>
						<th>m</th>
						<td>minute without leading zero</td>
						<th>mm</th>
						<td>minute with leading zero</td>
					</tr>
					<tr>
						<th>s</th>
						<td>second without leading zero</td>
						<th>ss</th>
						<td>second with leading zero</td>
					</tr>
					<tr>
						<th>t</th>
						<td>a/p</td>
						<th>T</th>
						<td>A/P</td>
					</tr>
					<tr>
						<th>tt</th>
						<td>am/pm</td>
						<th>TT</th>
						<td>AM/PM</td>
					</tr>
				</table>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">UI Theme:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#uiTheme" id="#prefix#uiTheme" class="cs_dlgControl" value="#currentValues.uiTheme#" size="40">
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Field ID:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#fldID" id="#prefix#fldID" class="cs_dlgControl" value="#currentValues.fldID#" size="40">
				<br/><span>Please enter the field ID to be used via JavaScript.  If blank, will use default CS field name.</span>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Show Icon next to Field:</td>
			<td class="cs_dlgLabelSmall">
				<label>
					<input type="radio" name="#prefix#fldIcon" id="#prefix#fldIcon_none" value="none" <cfif currentValues.fldIcon eq 'none'>checked</cfif>>No
				</label>
				&nbsp;&nbsp;
				<label>
					<input type="radio" name="#prefix#fldIcon" id="#prefix#fldIcon_clock" value="clock" <cfif currentValues.fldIcon eq 'clock'>checked</cfif>>
					<img class="ui-timepicker-trigger" id="#prefix#fldIcon_timeIMG" src="/ADF/apps/pt_calendar/images/clock.png" alt="clock" title="Set a Time...">
				</label>
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" colspan="2" style="font-size:7pt;">
				<hr />
				ADF Custom Field v#fieldVersion#
			</td>
		</tr>
	</table>
</cfoutput>