<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright
Custom Field Type:
	calendar date picker
Name:
	calendar_date_picker_render.cfm
Summary:
	A custom checkbox field that is used to select dates within the Calendar App
ADF Requirements:
	date_1_0
	scripts_1_0
History:
	2011-07-28 - GAC - Created
	2015-05-01 - DJM - Converted to CFC
	2015-05-14 - DRM - Remove displayType options, use jQueryUI UItimepickerAddon always
						  - Use loose parsing, much more reliable in this situation
	2015-05-20 - DRM - Add and use formatLikePlugin() to format date in cf when dlg first opens like the plugin does in js
						  - Add getMinHeight()
	2015-06-05 - DRM - Provide a default time format, jQuery plugin doesn't work correctly if it's blank
						  - Remove form min-height css
	2016-02-25 - DRM - Resource detection support
--->
<cfcomponent displayName="CalendarTimePicker Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var readOnly = (arguments.displayMode EQ 'readonly') ? true : false;
		var displayValue = "";
		// Get from the App.cfc so all time fields use the same date in date/time stamp
		var standardDate = application.ptCalendar.getTimeDummyDate();
		// Set the Time mask to the App standard
		//var cfTimeMask = application.ptCalendar.getDisplayCFtimeMask();
		// Set Default Icon Options 
		var useClockIcon = false;
		// use default displayFormat if none is spec'd
		if (len(trim(inputParameters.displayFormat)) EQ 0)
			inputParameters.displayFormat = "h:mm TT";
	
		if (len(trim(currentValue)))
		{
			// Fix bad or incorrect date/time entries stored
			currentValue = application.ptCalendar.date.csDateFormat(currentValue, currentValue);
			// Strip the standardDate from the currentValueand do a TimeFormat for Display
			displayValue = formatLikePlugin(trim(replace(currentValue, standardDate, "", "ALL")), inputParameters.displayFormat);
		}
		
		inputParameters = setDefaultParameters(argumentCollection=arguments);
		
		if (inputParameters.fldIcon EQ "clock")
			useClockIcon = true;
	</cfscript>
	
	<cfscript>
		renderJSFunctions(argumentCollection=arguments,fieldParameters=inputParameters,standardDate=standardDate,useClockIcon=useClockIcon);
	</cfscript>
	
	<cfoutput>
		<input type="text" name="#arguments.fieldName#_picker" id="#inputParameters.fldID#_picker" value="#displayValue#" autocomplete="off" size="10"<cfif readOnly> disabled</cfif>>
		<cfif useClockIcon>
			<img class="ui-timepicker-trigger" id="#inputParameters.fldID#_timeIMG" src="/ADF/apps/pt_calendar/images/clock.png" alt="clock" title="Set a Time...">
		</cfif>
		<!--- hidden field to store the value --->
		<input type='hidden' name='#arguments.fieldName#' id='#inputParameters.fldID#' value='#currentValue#'>
		<!--- <input type='text' name='#arguments.fieldName#_dtObject' id='#inputParameters.fldID#_dtObject' value=''> --->
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldParameters" type="struct" required="yes">
	<cfargument name="standardDate" type="string" required="yes">
	<cfargument name="useClockIcon" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.fieldParameters);
	</cfscript>
<cfoutput><script type="text/javascript">
<!--
jQuery(function() {
	// jQueryUI TimePicker Addon
	// http://trentrichardson.com/examples/timepicker/	
	
	// jQueryUI TimePicker Addon Options
	var timePickerAddonOptions_#arguments.fieldName# = {
				timeFormat: '#inputParameters.displayFormat#'
				,hourGrid: 6
				,minuteGrid: 15
				,parse: 'loose'
			};

	// Calendar Picker Fields
	jQuery("###inputParameters.fldID#_picker").timepicker( timePickerAddonOptions_#arguments.fieldName# );

	// Set the Clock or the Calendar Image to activate the Date/Time picker flyout 
<cfif arguments.useClockIcon>
	jQuery("###inputParameters.fldID#_timeIMG").click(function(){
		jQuery("###inputParameters.fldID#_picker").focus();					
	});
</cfif>

	// Onchange populate the Hidden field that stores the data
	jQuery("###inputParameters.fldID#_picker").change(function(){	
		var timeStr = jQuery("###inputParameters.fldID#_picker").val();
		var dateStr = '#arguments.standardDate#';
		
		var csDate = "";
		var jsDateObj = "";
		
		// Use DateJS lib to parse the concatenated date/time into a date/time object
		if ( jQuery.trim(dateStr).length && jQuery.trim(timeStr).length )
			jsDateObj = Date.parse(dateStr + " " + timeStr);

		// Use the dateFormat Lib to convert the date/time object to a CS Date string
		if ( jQuery.trim(jsDateObj).length )
			csDate=dateFormat(jsDateObj, "yyyy-mm-dd HH:MM:00");
			
		// Set the value to the hidden field to be stored
		jQuery("input[name=#arguments.fieldName#]").val(csDate);
		
		
		//jQuery("input[name=#arguments.fieldName#_dtObject]").val(jsDateObj);
	});
	
	/* Date Parsing Function */
	/* function parseTime(tm){
		var yearStr = Year(arguments.standardDate);
		var mthStr = (#Month(arguments.standardDate)# - 1);
		var dayStr = #Day(arguments.standardDate)#;
		var pDate = new Date(yearStr,mthStr,dayStr);
		// Parse the time and then add the parts to the DateObject
		var pTime = tm.match(/(\d+)(?::(\d\d))?\s*(p?)/);
		// Create the Date Object
		//d.setFullYear( parseInt(yearStr) );
		///d.setMonth( parseInt(mthStr - 1) ); // javacript months are from: 0-11
		//d.setDate( parseInt(dayStr) );
		pDate.setHours( parseInt(pTime[1]) + (pTime[3] ? 12 : 0) );
		pDate.setMinutes( parseInt(pTime[2]) || 0 );
		pDate.setSeconds( 0 );
		// Return the date object
		return pDate;		
	}*/
});
//-->
</script></cfoutput>
</cffunction>

<cffunction name="setDefaultParameters" returntype="struct" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		// Validate if the property field has been defined
		if ( NOT StructKeyExists(inputParameters, "displayFormat") OR LEN(inputParameters.displayFormat) LTE 0 )
			inputParameters.displayFormat = "h:mm tt";
		if ( NOT StructKeyExists(inputParameters, "uiTheme") OR LEN(inputParameters.uiTheme) LTE 0 )
			inputParameters.uiTheme = application.ptCalendar.getUItheme(); // use the UI theme from the Configuration Element
		if ( NOT StructKeyExists(inputParameters, "fldIcon") OR LEN(inputParameters.fldIcon) LTE 0 )
			inputParameters.fldIcon = "none";
		if ( NOT StructKeyExists(inputParameters, "fldID") OR LEN(inputParameters.fldID) LTE 0 )
			inputParameters.fldID = TRIM(arguments.fieldName);
		else 
			inputParameters.fldID = TRIM(inputParameters.fldID);
		
		return inputParameters;
	</cfscript>
</cffunction>

<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "TEXT")';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please select a value for the #arguments.label# field.";
	}

	// field types that require some particular minimum height should return the desired number of pixels
	public numeric function getMinHeight()
	{
		return 150;
	}

	// formats passed time using a format in the style used by the jQuery UI timepicker plugin
	function formatLikePlugin(time, format)
	{
		var str = timeFormat(arguments.time, arguments.format);
		if (find("tt", arguments.format))
			str = replaceList(str, "AM,PM", "am,pm");
		else if (find("t", arguments.format))
			str = replaceList(str, "A,P", "a,p");
		return str;
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,jQueryUI,DateJS,DateFormat,jQueryUITimepickerAddon");
	}
	public string function loadResourceDependencies()
	{
		var inputParameters = setDefaultParameters(argumentCollection=arguments);
		application.ptCalendar.scripts.loadJQuery();
		application.ptCalendar.scripts.loadJQueryUI(themeName=inputParameters.uiTheme);
		application.ptCalendar.scripts.loadDateJS();
		application.ptCalendar.scripts.loadDateFormat();
		application.ptCalendar.scripts.loadJQueryUITimepickerAddon();
	}
</cfscript>
</cfcomponent>